edges

package
v0.13.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2024 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// EnumToString is a helper map for marshalling the enum
	EnumToString = map[Edge_e]string{
		None:      "",
		Ford:      "Ford",
		Pass:      "Pass",
		River:     "River",
		StoneRoad: "Stone Road",
	}
	// StringToEnum is a helper map for unmarshalling the enum
	StringToEnum = map[string]Edge_e{
		"":           None,
		"Ford":       Ford,
		"Pass":       Pass,
		"River":      River,
		"Stone Road": StoneRoad,
	}
)

Functions

This section is empty.

Types

type Edge_e

type Edge_e int

Edge_e is an enum for the edge of a hex.

const (
	None Edge_e = iota
	Ford
	Pass
	River
	StoneRoad
)

func (Edge_e) MarshalJSON

func (e Edge_e) MarshalJSON() ([]byte, error)

MarshalJSON implements the json.Marshaler interface.

func (Edge_e) String

func (e Edge_e) String() string

String implements the fmt.Stringer interface.

func (*Edge_e) UnmarshalJSON

func (e *Edge_e) UnmarshalJSON(data []byte) error

UnmarshalJSON implements the json.Unmarshaler interface.

Jump to