Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // EnumToString is a helper map for marshalling the enum EnumToString = map[Edge_e]string{ None: "", Ford: "Ford", Pass: "Pass", River: "River", StoneRoad: "Stone Road", } // StringToEnum is a helper map for unmarshalling the enum StringToEnum = map[string]Edge_e{ "": None, "Ford": Ford, "Pass": Pass, "River": River, "Stone Road": StoneRoad, } )
Functions ¶
This section is empty.
Types ¶
type Edge_e ¶
type Edge_e int
Edge_e is an enum for the edge of a hex.
func (Edge_e) MarshalJSON ¶
MarshalJSON implements the json.Marshaler interface.
func (*Edge_e) UnmarshalJSON ¶
UnmarshalJSON implements the json.Unmarshaler interface.
Click to show internal directories.
Click to hide internal directories.